@@ -265,56 +265,6 @@ def _get_outdated_versioned_modules_of_deptree(modules):
                 yield dep
 
 
-@odoo_module.command(
-    help=("If menu items are missing, then recomputing the parent store" "can help")
-)
-@pass_config
-@click.pass_context
-def recompute_parent_store(ctx, config):
-    if config.use_docker:
-        from .lib_control_with_docker import shell as lib_shell
-
-    click.secho("Recomputing parent store...", fg="blue")
-    lib_shell(
-        config,
-        (
-            "for model in self.env['ir.model'].search([]):\n"
-            "   try:\n"
-            "       obj = self.env[model.model]\n"
-            "   except KeyError: pass\n"
-            "   else:\n"
-            "       obj._parent_store_compute()\n"
-            "       env.cr.commit()\n"
-        ),
-    )
-    click.secho("Recompute parent store done.", fg="green")
-
-
-@odoo_module.command(
-    help=(
-        "As the name says: if db was transferred, web-icons are restored"
-        " on missing assets"
-    )
-)
-@pass_config
-@click.pass_context
-def restore_web_icons(ctx, config):
-    if config.use_docker:
-        from .lib_control_with_docker import shell as lib_shell
-
-    click.secho("Restoring web icons...", fg="blue")
-    lib_shell(
-        config,
-        (
-            "for x in self.env['ir.ui.menu'].search([]):\n"
-            "   if not x.web_icon: continue\n"
-            "   x.web_icon_data = x._compute_web_icon_data(x.web_icon)\n"
-            "   env.cr.commit()\n"
-        ),
-    )
-    click.secho("Restored web icons.", fg="green")
-
-
 def _get_available_modules(ctx, param, incomplete):
     from .odoo_config import MANIFEST
 
@@ -876,20 +826,6 @@ def update_i18n(ctx, config, module, no_restart):
         Commands.invoke(ctx, "restart", machines=["odoo"])
 
 
-@odoo_module.command()
-@pass_config
-def progress(config):
-    """
-    Displays installation progress
-    """
-    for row in _execute_sql(
-        config.get_odoo_conn(),
-        "select state, count(*) from ir_module_module group by state;",
-        fetchall=True,
-    ):
-        click.echo("{}: {}".format(row[0], row[1]))
-
-
 @odoo_module.command(name="show-install-state")
 @pass_config
 def show_install_state(config, suppress_error=False, missing_as_error=False):
@@ -927,13 +863,6 @@ def show_addons_paths():
         click.echo(path)
 
 
-@odoo_module.command(name="pretty-print-manifest")
-def pretty_print_manifest():
-    from .odoo_config import MANIFEST
-
-    MANIFEST().rewrite()
-
-
 @odoo_module.command(name="show-conflicting-modules")
 def show_conflicting_modules():
     from .odoo_config import get_odoo_addons_paths
@@ -1297,36 +1226,6 @@ def unittest(
         sys.exit(-1)
 
 
-@odoo_module.command()
-@click.argument("name", required=True)
-@click.option("-Q", "--quick", is_flag=True)
-@pass_config
-@click.pass_context
-def set_ribbon(ctx, config, name, quick):
-    if not quick:
-        SQL = """
-            Select state from ir_module_module where name = 'web_environment_ribbon';
-        """
-        res = _execute_sql(config.get_odoo_conn(), SQL, fetchone=True)
-        if not (res and res[0] == "installed"):
-            Commands.invoke(
-                ctx, "update", module=["web_environment_ribbon"], no_dangling_check=True
-            )
-
-    _execute_sql(
-        config.get_odoo_conn(),
-        """
-        UPDATE
-            ir_config_parameter
-        SET
-            value = %s
-        WHERE
-            key = 'ribbon.name';
-    """,
-        params=(name,),
-    )
-
-
 @odoo_module.command(help="For directly installed odoos.")
 @pass_config
 @click.pass_context
@@ -1465,6 +1364,7 @@ def list_deps(ctx, config, module, no_cache):
 
     started = arrow.get()
     from .module_tools import Modules, DBModules, Module
+    from .module_tools import NotInAddonsPath
     from .odoo_config import customs_dir
     from .consts import FILE_DIRHASHES
 
@@ -1503,7 +1403,11 @@ def list_deps(ctx, config, module, no_cache):
         # get some hashes:
         paths = _get_global_hash_paths(True)
         for mod in data["modules"]:
-            paths.append(Module.get_by_name(mod).path)
+            try:
+                objmod = Module.get_by_name(mod)
+                paths.append(objmod.path)
+            except NotInAddonsPath:
+                pass
         for mod in data["auto_install"]:
             paths.append(Module.get_by_name(mod).path)
 
@@ -1575,6 +1479,5 @@ def list_modules(ctx, config):
         print(m)
 
 
-Commands.register(progress)
 Commands.register(update)
 Commands.register(show_install_state)
